Trait Display

pub trait Display: HasDisplayHandle + 'static { }
An owned display handle that can be used in a Compositor.

This is just a convenient super trait of the raw-window-handle trait.

Implementors



impl<T> Display for T
where T: HasDisplayHandle + 'static,